@@ -1,8 +1,8 @@
 /*
    File locking
 
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2011
-   The Free Software Foundation, Inc.
+   Copyright (C) 2003-2014
+   Free Software Foundation, Inc.
 
    Written by:
    Adam Byrtek, 2003
