@@ -1,8 +1,8 @@
 /*
    paths to configuration files
 
-   Copyright (C) 2010, 2011
-   The Free Software Foundation, Inc.
+   Copyright (C) 2010-2014
+   Free Software Foundation, Inc.
 
    Written by:
    Slava Zanko <slavazanko@gmail.com>, 2010.
