@@ -1,29 +1,31 @@
-/* Widgets for the Midnight Commander
+/*
+   Widgets for the Midnight Commander
 
-   Copyright (C) 1994, 1995, 1996, 1998, 1999, 2000, 2001, 2002, 2003,
-   2004, 2005, 2006, 2007, 2009, 2010 Free Software Foundation, Inc.
+   Copyright (C) 1994-2014
+   Free Software Foundation, Inc.
 
-   Authors: 1994, 1995 Radek Doulik
-   1994, 1995 Miguel de Icaza
-   1995 Jakub Jelinek
-   1996 Andrej Borsenkow
-   1997 Norbert Warmuth
-   2009, 2010 Andrew Borodin
+   Authors:
+   Radek Doulik, 1994, 1995
+   Miguel de Icaza, 1994, 1995
+   Jakub Jelinek, 1995
+   Andrej Borsenkow, 1996
+   Norbert Warmuth, 1997
+   Andrew Borodin <aborodin@vmail.ru>, 2009, 2010, 2013
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
+   This file is part of the Midnight Commander.
 
-   This program is distributed in the hope that it will be useful,
+   The Midnight Commander is free software: you can redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software Foundation, either version 3 of the License,
+   or (at your option) any later version.
+
+   The Midnight Commander is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /** \file groupbox.c
@@ -50,41 +52,43 @@
 /*** file scope functions ************************************************************************/
 
 static cb_ret_t
-groupbox_callback (Widget * w, widget_msg_t msg, int parm)
+groupbox_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm, void *data)
 {
-    WGroupbox *g = (WGroupbox *) w;
+    WGroupbox *g = GROUPBOX (w);
 
     switch (msg)
     {
-    case WIDGET_INIT:
+    case MSG_INIT:
         return MSG_HANDLED;
 
-    case WIDGET_FOCUS:
+    case MSG_FOCUS:
         return MSG_NOT_HANDLED;
 
-    case WIDGET_DRAW:
+    case MSG_DRAW:
         {
-            gboolean disabled = (w->options & W_DISABLED) != 0;
+            gboolean disabled;
+
+            disabled = (w->options & W_DISABLED) != 0;
             tty_setcolor (disabled ? DISABLED_COLOR : COLOR_NORMAL);
-            draw_box (g->widget.owner, g->widget.y - g->widget.owner->y,
-                      g->widget.x - g->widget.owner->x, g->widget.lines, g->widget.cols, TRUE);
+            tty_draw_box (w->y, w->x, w->lines, w->cols, TRUE);
 
             if (g->title != NULL)
             {
+                Widget *wo = WIDGET (w->owner);
+
                 tty_setcolor (disabled ? DISABLED_COLOR : COLOR_TITLE);
-                dlg_move (g->widget.owner, g->widget.y - g->widget.owner->y,
-                          g->widget.x - g->widget.owner->x + 1);
+                widget_move (wo, w->y - wo->y, w->x - wo->x + 1);
                 tty_print_string (g->title);
             }
             return MSG_HANDLED;
         }
 
-    case WIDGET_DESTROY:
+    case MSG_DESTROY:
         g_free (g->title);
         return MSG_HANDLED;
 
     default:
-        return default_proc (msg, parm);
+        return widget_default_callback (w, sender, msg, parm, data);
     }
 }
 
@@ -96,15 +100,31 @@ WGroupbox *
 groupbox_new (int y, int x, int height, int width, const char *title)
 {
     WGroupbox *g;
+    Widget *w;
 
     g = g_new (WGroupbox, 1);
-    init_widget (&g->widget, y, x, height, width, groupbox_callback, NULL);
+    w = WIDGET (g);
+    widget_init (w, y, x, height, width, groupbox_callback, NULL);
 
-    widget_want_cursor (g->widget, FALSE);
-    widget_want_hotkey (g->widget, FALSE);
+    widget_want_cursor (w, FALSE);
+    widget_want_hotkey (w, FALSE);
+
+    g->title = NULL;
+    groupbox_set_title (g, title);
+
+    return g;
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
+void
+groupbox_set_title (WGroupbox * g, const char *title)
+{
+    g_free (g->title);
+    g->title = NULL;
 
     /* Strip existing spaces, add one space before and after the title */
-    if (title != NULL)
+    if (title != NULL && *title != '\0')
     {
         char *t;
 
@@ -113,7 +133,7 @@ groupbox_new (int y, int x, int height, int width, const char *title)
         g_free (t);
     }
 
-    return g;
+    widget_redraw (WIDGET (g));
 }
 
 /* --------------------------------------------------------------------------------------------- */
