@@ -1,8 +1,8 @@
 /*
    Handle command line arguments.
 
-   Copyright (C) 2009, 2010, 2011, 2012
-   The Free Software Foundation, Inc.
+   Copyright (C) 2009-2014
+   Free Software Foundation, Inc.
 
    Written by:
    Slava Zanko <slavazanko@gmail.com>, 2009.
