@@ -1,8 +1,8 @@
 /*
    Editor book mark handling
 
-   Copyright (C) 2001, 2002, 2003, 2005, 2007, 2011
-   The Free Software Foundation, Inc.
+   Copyright (C) 2001-2014
+   Free Software Foundation, Inc.
 
    Written by:
    Paul Sheer, 1996, 1997
