@@ -1,8 +1,8 @@
 /*
    Editor spell checker
 
-   Copyright (C) 2012
-   The Free Software Foundation, Inc.
+   Copyright (C) 2012-2014
+   Free Software Foundation, Inc.
 
    Written by:
    Ilia Maslakov <il.smind@gmail.com>, 2012
@@ -35,6 +35,8 @@
 #endif
 #include "lib/strutil.h"
 
+#include "src/setup.h"
+
 #include "edit-impl.h"
 #include "spell.h"
 
@@ -71,9 +73,7 @@ static struct AspellStringEnumeration *(*mc_aspell_word_list_elements) (const st
                                                                         * ths);
 static const char *(*mc_aspell_config_retrieve) (struct AspellConfig * ths, const char *key);
 static void (*mc_delete_aspell_speller) (struct AspellSpeller * ths);
-/*
-   static void (*mc_delete_aspell_config) (struct AspellConfig * ths);
- */
+static void (*mc_delete_aspell_config) (struct AspellConfig * ths);
 static void (*mc_delete_aspell_can_have_error) (struct AspellCanHaveError * ths);
 static const char *(*mc_aspell_error_message) (const struct AspellCanHaveError * ths);
 static void (*mc_delete_aspell_string_enumeration) (struct AspellStringEnumeration * ths);
@@ -131,7 +131,7 @@ static struct
  * Found the language name by language code. For example: en_US -> American English.
  *
  * @param code Short name of the language (ru, en, pl, uk, etc...)
- * @returns the language name
+ * @return language name
  */
 
 static const char *
@@ -152,7 +152,7 @@ spell_decode_lang (const char *code)
 /**
  * Checks if aspell library and symbols are available.
  *
- * @returns FALSE or error
+ * @return FALSE or error
  */
 
 static gboolean
@@ -228,7 +228,7 @@ spell_available (void)
         (spell_module, "delete_aspell_speller", (void *) &mc_delete_aspell_speller))
         goto error_ret;
 
-    if (!g_module_symbol (spell_module, "delete_aspell_config", (void *) &mc_delete_aspell_speller))
+    if (!g_module_symbol (spell_module, "delete_aspell_config", (void *) &mc_delete_aspell_config))
         goto error_ret;
 
     if (!g_module_symbol (spell_module, "delete_aspell_string_enumeration",
@@ -286,6 +286,9 @@ aspell_init (void)
 {
     AspellCanHaveError *error = NULL;
 
+    if (strcmp (spell_language, "NONE") == 0)
+        return;
+
     if (global_speller != NULL)
         return;
 
@@ -303,6 +306,9 @@ aspell_init (void)
     global_speller->config = mc_new_aspell_config ();
     global_speller->speller = NULL;
 
+    if (spell_language != NULL)
+        mc_aspell_config_replace (global_speller->config, "lang", spell_language);
+
     error = mc_new_aspell_speller (global_speller->config);
 
     if (mc_aspell_error_number (error) == 0)
@@ -311,7 +317,7 @@ aspell_init (void)
     {
         edit_error_dialog (_("Error"), mc_aspell_error_message (error));
         mc_delete_aspell_can_have_error (error);
-        g_free (global_speller);
+        aspell_clean ();
     }
 }
 
@@ -326,7 +332,12 @@ aspell_clean (void)
     if (global_speller == NULL)
         return;
 
-    mc_delete_aspell_speller (global_speller->speller);
+    if (global_speller->speller != NULL)
+        mc_delete_aspell_speller (global_speller->speller);
+
+    if (global_speller->config != NULL)
+        mc_delete_aspell_config (global_speller->config);
+
     g_free (global_speller);
     global_speller = NULL;
 
@@ -339,7 +350,7 @@ aspell_clean (void)
  * Get array of available languages.
  *
  * @param lang_list Array of languages. Must be cleared before use
- * @returns language list length
+ * @return language list length
  */
 
 unsigned int
@@ -403,7 +414,7 @@ aspell_array_clean (GArray * array)
 /**
  * Get the current language name.
  *
- * @returns Language name
+ * @return language name
  */
 
 const char *
@@ -419,8 +430,8 @@ aspell_get_lang (void)
 /**
  * Set the language.
  *
- * @param Language name
- * @returns FALSE or error
+ * @param lang Language name
+ * @return FALSE or error
  */
 
 gboolean
@@ -428,10 +439,12 @@ aspell_set_lang (const char *lang)
 {
     if (lang != NULL)
     {
-        int res;
         AspellCanHaveError *error;
         const char *spell_codeset;
 
+        g_free (spell_language);
+        spell_language = g_strdup (lang);
+
 #ifdef HAVE_CHARSET
         if (mc_global.source_codepage > 0)
             spell_codeset = get_codepage_id (mc_global.source_codepage);
@@ -439,8 +452,8 @@ aspell_set_lang (const char *lang)
 #endif
             spell_codeset = str_detect_termencoding ();
 
-        res = mc_aspell_config_replace (global_speller->config, "lang", lang);
-        res = mc_aspell_config_replace (global_speller->config, "encoding", spell_codeset);
+        mc_aspell_config_replace (global_speller->config, "lang", lang);
+        mc_aspell_config_replace (global_speller->config, "encoding", spell_codeset);
 
         /* the returned pointer should _not_ need to be deleted */
         if (global_speller->speller != NULL)
@@ -466,7 +479,7 @@ aspell_set_lang (const char *lang)
  *
  * @param word Word for spell check
  * @param word_size Word size (in bytes)
- * @returns FALSE if word is not in the dictionary
+ * @return FALSE if word is not in the dictionary
  */
 
 gboolean
@@ -487,7 +500,7 @@ aspell_check (const char *word, const int word_size)
  * @param suggest array of words to iterate through
  * @param word Word for spell check
  * @param word_size Word size (in bytes)
- * @returns count of suggests for the word
+ * @return count of suggests for the word
  */
 
 unsigned int
@@ -530,7 +543,7 @@ aspell_suggest (GArray * suggest, const char *word, const int word_size)
  *
  * @param word Word for spell check
  * @param word_size  Word size (in bytes)
- * @returns FALSE or error
+ * @return FALSE or error
  */
 gboolean
 aspell_add_to_dict (const char *word, int word_size)
