@@ -1,9 +1,8 @@
 /*
    Directory hotlist -- for the Midnight Commander
 
-   Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-   2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
-   The Free Software Foundation, Inc.
+   Copyright (C) 1994-2014
+   Free Software Foundation, Inc.
 
    Written by:
    Radek Doulik, 1994
@@ -242,7 +241,7 @@ update_path_name (void)
     WListbox *list = hotlist_state.moving ? l_movelist : l_hotlist;
     Widget *w = WIDGET (list);
 
-    if (list->count != 0)
+    if (!listbox_is_empty (list))
     {
         char *ctext = NULL;
         void *cdata = NULL;
@@ -350,7 +349,7 @@ hotlist_button_callback (WButton * button, int action)
             struct hotlist *moveto_group = NULL;
             int ret;
 
-            if (l_hotlist->count == 0)
+            if (listbox_is_empty (l_hotlist))
                 return 0;       /* empty group - nothing to do */
 
             listbox_get_current (l_hotlist, NULL, (void **) &item);
@@ -594,7 +593,7 @@ hotlist_listbox_callback (WListbox * list)
 {
     WDialog *dlg = WIDGET (list)->owner;
 
-    if (list->count != 0)
+    if (!listbox_is_empty (list))
     {
         void *data = NULL;
 
