@@ -8,9 +8,8 @@
    created and destroyed.  This is required for the future vfs layer,
    it will be possible to have tree views over virtual file systems.
 
-   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2009,
-   2011, 2013
-   The Free Software Foundation, Inc.
+   Copyright (C) 1999-2014
+   Free Software Foundation, Inc.
 
    Written by:
    Janne Kukonlehto, 1994, 1996
@@ -207,9 +206,7 @@ static int
 tree_store_load_from (char *name)
 {
     FILE *file;
-    char buffer[MC_MAXPATHLEN + 20], oldname[MC_MAXPATHLEN];
-    char *different;
-    int common;
+    char buffer[MC_MAXPATHLEN + 20];
     int do_load;
 
     g_return_val_if_fail (name != NULL, FALSE);
@@ -239,6 +236,8 @@ tree_store_load_from (char *name)
 
     if (do_load)
     {
+        char oldname[MC_MAXPATHLEN];
+
         ts.loaded = TRUE;
 
         /* File open -> read contents */
@@ -264,8 +263,11 @@ tree_store_load_from (char *name)
                 /* Clear-text decompression */
                 char *s = strtok (lc_name, " ");
 
-                if (s)
+                if (s != NULL)
                 {
+                    char *different;
+                    int common;
+
                     common = atoi (s);
                     different = strtok (NULL, "");
                     if (different)
@@ -344,10 +346,10 @@ tree_store_save_to (char *name)
     current = ts.tree_first;
     while (current)
     {
-        int i, common;
-
         if (vfs_file_is_local (current->name))
         {
+            int i, common;
+
             /* Clear-text compression */
             if (current->prev && (common = str_common (current->prev->name, current->name)) > 2)
             {
@@ -482,11 +484,11 @@ static void
 tree_store_notify_remove (tree_entry * entry)
 {
     hook_t *p = remove_entry_hooks;
-    tree_store_remove_fn r;
 
     while (p != NULL)
     {
-        r = (tree_store_remove_fn) p->hook_fn;
+        tree_store_remove_fn r = (tree_store_remove_fn) p->hook_fn;
+
         r (entry, p->hook_data);
         p = p->next;
     }
@@ -689,7 +691,7 @@ tree_store_remove_entry_remove_hook (tree_store_remove_fn callback)
 void
 tree_store_remove_entry (const vfs_path_t * name_vpath)
 {
-    tree_entry *current, *base, *old;
+    tree_entry *current, *base;
     size_t len;
 
     g_return_if_fail (name_vpath != NULL);
@@ -715,10 +717,14 @@ tree_store_remove_entry (const vfs_path_t * name_vpath)
     while (current != NULL && vfs_path_equal_len (current->name, base->name, len))
     {
         gboolean ok;
+        tree_entry *old;
+        const char *cname;
 
-        ok = (current->name->str[len] == '\0' || current->name->str[len] == PATH_SEP);
+        cname = vfs_path_as_str (current->name);
+        ok = (cname[len] == '\0' || cname[len] == PATH_SEP);
         if (!ok)
             break;
+
         old = current;
         current = current->next;
         remove_entry (old);
@@ -736,6 +742,8 @@ tree_store_mark_checked (const char *subname)
     vfs_path_t *name;
     tree_entry *current, *base;
     int flag = 1;
+    const char *cname;
+
     if (!ts.loaded)
         return;
 
@@ -743,10 +751,11 @@ tree_store_mark_checked (const char *subname)
         return;
 
     /* Calculate the full name of the subdirectory */
-    if (subname[0] == '.' && (subname[1] == 0 || (subname[1] == '.' && subname[2] == 0)))
+    if (DIR_IS_DOT (subname) || DIR_IS_DOTDOT (subname))
         return;
 
-    if (ts.check_name->str[0] == PATH_SEP && ts.check_name->str[1] == 0)
+    cname = vfs_path_as_str (ts.check_name);
+    if (cname[0] == PATH_SEP && cname[1] == '\0')
         name = vfs_path_build_filename (PATH_SEP_STR, subname, NULL);
     else
         name = vfs_path_append_new (ts.check_name, subname, NULL);
@@ -777,10 +786,11 @@ tree_store_mark_checked (const char *subname)
         {
             gboolean ok;
 
-            ok = (current->name->str[len] == '\0' || current->name->str[len] == PATH_SEP
-                  || len == 1);
+            cname = vfs_path_as_str (current->name);
+            ok = (cname[len] == '\0' || cname[len] == PATH_SEP || len == 1);
             if (!ok)
                 break;
+
             current->mark = 0;
             current = current->next;
         }
@@ -832,10 +842,13 @@ tree_store_start_check (const vfs_path_t * vpath)
     while (current != NULL && vfs_path_equal_len (current->name, ts.check_name, len))
     {
         gboolean ok;
+        const char *cname;
 
-        ok = (current->name->str[len] == '\0' || current->name->str[len] == PATH_SEP || len == 1);
+        cname = vfs_path_as_str (current->name);
+        ok = (cname[len] == '\0' || cname[len] == PATH_SEP || len == 1);
         if (!ok)
             break;
+
         current->mark = 1;
         current = current->next;
     }
@@ -849,7 +862,7 @@ tree_store_start_check (const vfs_path_t * vpath)
 void
 tree_store_end_check (void)
 {
-    tree_entry *current, *old;
+    tree_entry *current;
     size_t len;
     GList *the_queue;
 
@@ -865,11 +878,14 @@ tree_store_end_check (void)
     while (current != NULL && vfs_path_equal_len (current->name, ts.check_name, len))
     {
         gboolean ok;
+        tree_entry *old;
+        const char *cname;
 
-        ok = (current->name->str[len] == '\0' || current->name->str[len] == PATH_SEP || len == 1);
-
+        cname = vfs_path_as_str (current->name);
+        ok = (cname[len] == '\0' || cname[len] == PATH_SEP || len == 1);
         if (!ok)
             break;
+
         old = current;
         current = current->next;
         if (old->mark)
@@ -883,8 +899,7 @@ tree_store_end_check (void)
     vfs_path_free (ts.check_name);
     ts.check_name = NULL;
 
-    g_list_foreach (the_queue, (GFunc) vfs_path_free, NULL);
-    g_list_free (the_queue);
+    g_list_free_full (the_queue, (GDestroyNotify) vfs_path_free);
 }
 
 /* --------------------------------------------------------------------------------------------- */
@@ -893,7 +908,6 @@ tree_entry *
 tree_store_rescan (const vfs_path_t * vpath)
 {
     DIR *dirp;
-    struct dirent *dp;
     struct stat buf;
     tree_entry *entry;
 
@@ -911,22 +925,18 @@ tree_store_rescan (const vfs_path_t * vpath)
     dirp = mc_opendir (vpath);
     if (dirp)
     {
+        struct dirent *dp;
+
         for (dp = mc_readdir (dirp); dp; dp = mc_readdir (dirp))
         {
             vfs_path_t *tmp_vpath;
 
-            if (dp->d_name[0] == '.')
-            {
-                if (dp->d_name[1] == 0 || (dp->d_name[1] == '.' && dp->d_name[2] == 0))
-                    continue;
-            }
+            if (DIR_IS_DOT (dp->d_name) || DIR_IS_DOTDOT (dp->d_name))
+                continue;
 
             tmp_vpath = vfs_path_append_new (vpath, dp->d_name, NULL);
-            if (mc_lstat (tmp_vpath, &buf) != -1)
-            {
-                if (S_ISDIR (buf.st_mode))
-                    tree_store_mark_checked (dp->d_name);
-            }
+            if (mc_lstat (tmp_vpath, &buf) != -1 && S_ISDIR (buf.st_mode))
+                tree_store_mark_checked (dp->d_name);
             vfs_path_free (tmp_vpath);
         }
         mc_closedir (dirp);
