@@ -1,9 +1,8 @@
 /*
    Main program for the Midnight Commander
 
-   Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-   2003, 2004, 2005, 2006, 2007, 2009, 2011
-   The Free Software Foundation, Inc.
+   Copyright (C) 1994-2014
+   Free Software Foundation, Inc.
 
    Written by:
    Miguel de Icaza, 1994, 1995, 1996, 1997
@@ -292,15 +291,36 @@ main (int argc, char *argv[])
 
     vfs_init ();
     vfs_plugins_init ();
+
+    load_setup ();
+
+    /* Must be done after load_setup because depends on mc_global.vfs.cd_symlinks */
     vfs_setup_work_dir ();
 
+    /* Resolve the other_dir panel option. Must be done after vfs_setup_work_dir */
+    {
+        char *buffer;
+        vfs_path_t *vpath;
+
+        buffer = mc_config_get_string (mc_panels_config, "Dirs", "other_dir", ".");
+        vpath = vfs_path_from_str (buffer);
+        if (vfs_file_is_local (vpath))
+            saved_other_dir = buffer;
+        else
+            g_free (buffer);
+        vfs_path_free (vpath);
+    }
+
     /* Set up temporary directory after VFS initialization */
     mc_tmpdir ();
 
-    /* do this after vfs initialization due to mc_setctl() call in mc_setup_by_args() */
+    /* do this after vfs initialization and vfs working directory setup
+       due to mc_setctl() and mcedit_arg_vpath_new() calls in mc_setup_by_args() */
     if (!mc_setup_by_args (argc, argv, &error))
     {
         vfs_shut ();
+        done_setup ();
+        g_free (saved_other_dir);
         mc_event_deinit (NULL);
         goto startup_exit_falure;
     }
@@ -338,8 +358,6 @@ main (int argc, char *argv[])
     /* FIXME: Should be removed and LINES and COLS computed on subshell */
     tty_init (!mc_args__nomouse, mc_global.tty.xterm_flag);
 
-    load_setup ();
-
     /* start check mc_global.display_codepage and mc_global.source_codepage */
     check_codeset ();
 
@@ -352,7 +370,11 @@ main (int argc, char *argv[])
 
     tty_init_colors (mc_global.tty.disable_colors, mc_args__force_colors);
 
-    mc_skin_init (&error);
+    mc_skin_init (NULL, &error);
+    dlg_set_default_colors ();
+    input_set_default_colors ();
+    if (mc_global.mc_run_mode == MC_RUN_FULL)
+        command_set_default_colors ();
     if (error != NULL)
     {
         message (D_ERROR, _("Warning"), "%s", error->message);
@@ -360,8 +382,6 @@ main (int argc, char *argv[])
         error = NULL;
     }
 
-    dlg_set_default_colors ();
-
 #ifdef ENABLE_SUBSHELL
     /* Done here to ensure that the subshell doesn't  */
     /* inherit the file descriptors opened below, etc */
