@@ -2,9 +2,8 @@
    Internal file viewer for the Midnight Commander
    Interface functions
 
-   Copyright (C) 1994, 1995, 1996, 1998, 1999, 2000, 2001, 2002, 2003,
-   2004, 2005, 2006, 2007, 2009, 2011
-   The Free Software Foundation, Inc.
+   Copyright (C) 1994-2014
+   Free Software Foundation, Inc
 
    Written by:
    Miguel de Icaza, 1994, 1995, 1998
@@ -14,8 +13,8 @@
    Norbert Warmuth, 1997
    Pavel Machek, 1998
    Roland Illig <roland.illig@gmx.de>, 2004, 2005
-   Slava Zanko <slavazanko@google.com>, 2009
-   Andrew Borodin <aborodin@vmail.ru>, 2009
+   Slava Zanko <slavazanko@google.com>, 2009, 2013
+   Andrew Borodin <aborodin@vmail.ru>, 2009, 2013
    Ilia Maslakov <il.smind@gmail.com>, 2009
 
    This file is part of the Midnight Commander.
@@ -46,13 +45,10 @@
 #include "lib/util.h"           /* load_file_position() */
 #include "lib/widget.h"
 
-#include "src/main.h"
-
 #include "src/filemanager/layout.h"     /* menubar_visible */
 #include "src/filemanager/midnight.h"   /* the_menubar */
 
 #include "internal.h"
-#include "mcviewer.h"
 
 /*** global variables ****************************************************************************/
 
@@ -92,10 +88,11 @@ do_mcview_event (mcview_t * view, Gpm_Event * event, int *result)
 {
     screen_dimen y, x;
     Gpm_Event local;
-    Widget *w = (Widget *) view;
+    Widget *w = WIDGET (view);
 
     /* rest of the upper frame - call menu */
-    if (mcview_is_in_panel (view) && (event->type & GPM_DOWN) != 0 && event->y == w->owner->y + 1)
+    if (mcview_is_in_panel (view) && (event->type & GPM_DOWN) != 0 &&
+        event->y == WIDGET (w->owner)->y + 1)
     {
         *result = MOU_UNHANDLED;
         return FALSE;           /* don't draw viewer over menu */
@@ -182,7 +179,7 @@ mcview_event (Gpm_Event * event, void *data)
     mcview_t *view = (mcview_t *) data;
     int result;
 
-    if (!mouse_global_in_widget (event, (Widget *) data))
+    if (!mouse_global_in_widget (event, WIDGET (data)))
         return MOU_UNHANDLED;
 
     if (do_mcview_event (view, event, &result))
@@ -197,9 +194,10 @@ mcview_event (Gpm_Event * event, void *data)
 mcview_t *
 mcview_new (int y, int x, int lines, int cols, gboolean is_panel)
 {
-    mcview_t *view = g_new0 (mcview_t, 1);
+    mcview_t *view;
 
-    init_widget (&view->widget, y, x, lines, cols, mcview_callback, mcview_event);
+    view = g_new0 (mcview_t, 1);
+    widget_init (WIDGET (view), y, x, lines, cols, mcview_callback, mcview_event);
 
     view->hex_mode = FALSE;
     view->hexedit_mode = FALSE;
@@ -234,10 +232,10 @@ mcview_viewer (const char *command, const vfs_path_t * file_vpath, int start_lin
 {
     gboolean succeeded;
     mcview_t *lc_mcview;
-    Dlg_head *view_dlg;
+    WDialog *view_dlg;
 
     /* Create dialog and widgets, put them on the dialog */
-    view_dlg = create_dlg (FALSE, 0, 0, LINES, COLS, NULL, mcview_dialog_callback, NULL,
+    view_dlg = dlg_create (FALSE, 0, 0, LINES, COLS, NULL, mcview_dialog_callback, NULL,
                            "[Internal File Viewer]", NULL, DLG_WANT_TAB);
 
     lc_mcview = mcview_new (0, 0, LINES - 1, COLS, FALSE);
@@ -247,21 +245,15 @@ mcview_viewer (const char *command, const vfs_path_t * file_vpath, int start_lin
 
     view_dlg->get_title = mcview_get_title;
 
-    {
-        char *file;
-
-        file = vfs_path_to_str (file_vpath);
-        succeeded = mcview_load (lc_mcview, command, file, start_line);
-        g_free (file);
-    }
+    succeeded = mcview_load (lc_mcview, command, vfs_path_as_str (file_vpath), start_line);
 
     if (succeeded)
-        run_dlg (view_dlg);
+        dlg_run (view_dlg);
     else
         view_dlg->state = DLG_CLOSED;
 
     if (view_dlg->state == DLG_CLOSED)
-        destroy_dlg (view_dlg);
+        dlg_destroy (view_dlg);
 
     return succeeded;
 }
@@ -317,7 +309,7 @@ mcview_load (mcview_t * view, const char *command, const char *file, int start_l
         retval = mcview_load_command_output (view, command);
     else if (file != NULL && file[0] != '\0')
     {
-        int fd = -1;
+        int fd;
         char tmp[BUF_MEDIUM];
         struct stat st;
 
@@ -375,10 +367,26 @@ mcview_load (mcview_t * view, const char *command, const char *file, int start_l
             if (view->magic_mode && (type != COMPRESSION_NONE))
             {
                 char *tmp_filename;
+                vfs_path_t *vpath1;
+                int fd1;
 
-                vfs_path_free (view->filename_vpath);
                 tmp_filename = g_strconcat (file, decompress_extension (type), (char *) NULL);
-                view->filename_vpath = vfs_path_from_str (tmp_filename);
+                vpath1 = vfs_path_from_str (tmp_filename);
+                fd1 = mc_open (vpath1, O_RDONLY | O_NONBLOCK);
+                if (fd1 == -1)
+                {
+                    g_snprintf (tmp, sizeof (tmp), _("Cannot open \"%s\" in parse mode\n%s"),
+                                file, unix_error_string (errno));
+                    mcview_show_error (view, tmp);
+                }
+                else
+                {
+                    mc_close (fd);
+                    fd = fd1;
+                    mc_fstat (fd, &st);
+                }
+                vfs_path_free (vpath1);
+
                 g_free (tmp_filename);
             }
             mcview_set_datasource_file (view, fd, &st);
